@@ -1,7 +1,8 @@
 import numpy as np
+import re
 import time
 import trimesh
-import pykin.utils.plot_utils as p_utils
+from pykin.utils import plot_utils as p_utils
 
 JOINT_TYPE_MAP = {'revolute'  : 'revolute',
                   'fixed'     : 'fixed',
@@ -84,7 +85,8 @@ def convert_string_to_narray(str_input):
         np.array: Returns string to np.array
     """
     if str_input is not None:
-        return np.array([float(data) for data in str_input.split()])
+        str_list = re.split(' |, ', str_input)
+        return np.array([float(data) for data in str_list])
 
 
 def calc_pose_error(tar_pose, cur_pose, EPS):
@@ -248,4 +250,4 @@ def get_spehre_param(link_type):
 
 def get_box_param(link_type):
     size = list(link_type.gparam.get('size'))
-    return size
\ No newline at end of file
+    return size
